==> Paws-0.02.tar.gz: Paws-0.02/lib/Paws/OpsWorks/GetHostnameSuggestion.pm <==

package Paws::OpsWorks::GetHostnameSuggestion {
  use Moose;
  has LayerId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetHostnameSuggestion');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::OpsWorks::GetHostnameSuggestionResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::GetHostnameSuggestion - Arguments for method GetHostnameSuggestion on Paws::OpsWorks

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetHostnameSuggestion on the 
AWS OpsWorks service. Use the attributes of this class
as arguments to method GetHostnameSuggestion.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to GetHostnameSuggestion.

As an example:

  $service_obj->GetHostnameSuggestion(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> LayerId => Str

  

The layer ID.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for GetHostnameSuggestion in Paws::OpsWorks

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.15.tar.gz: Paws-0.15/lib/Paws/OpsWorks/GetHostnameSuggestion.pm <==

package Paws::OpsWorks::GetHostnameSuggestion;
  use Moose;
  has LayerId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetHostnameSuggestion');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::OpsWorks::GetHostnameSuggestionResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::GetHostnameSuggestion - Arguments for method GetHostnameSuggestion on Paws::OpsWorks

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetHostnameSuggestion on the 
AWS OpsWorks service. Use the attributes of this class
as arguments to method GetHostnameSuggestion.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to GetHostnameSuggestion.

As an example:

  $service_obj->GetHostnameSuggestion(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> LayerId => Str

  

The layer ID.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetHostnameSuggestion in L<Paws::OpsWorks>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
